@@ -2,9 +2,9 @@
 from collections import deque
 
 import numpy
-from scipy import linalg
-from scipy import dot
-import scipy
+#from scipy import linalg
+#from scipy import dot
+#import scipy
 
 
 ## Original: http://www.ece.arizona.edu/~denny/python_nest/graph_lib_1.0.1.html
@@ -61,7 +61,7 @@ class GraphException(Exception):
     def __str__(self):
         return repr(self.value)
 
-class Graph:
+class graph:
     """ A graph with edges, nodes, and edge types """
     def __init__(self):
         self.next_edge_id = 0
@@ -670,170 +670,3 @@ class Graph:
                 
         return incidMatrix
     
-    def _gMatrix(self, alpha=0.85, nodelist=None):
-        M = self.adjacencyMatrix()
-        (n,m) = M.shape
-        
-        Danglers = numpy.where(M.sum(axis=1)==0)
-        
-        for d in Danglers[0]:
-            M[d]=1.0/n
-        
-        M=M/M.sum(axis=1)
-        
-        P = alpha * M + (1 - alpha) * numpy.ones((n,n)) / n
-        return P
-    
-    def pageRank(self, alpha=0.85, max_iter=100, Tolerance=1.0e-6, nodelist=None):
-        M = self._gMatrix(alpha, nodelist)   
-        (n,m) = M.shape
-        ## should be square
-        x = numpy.ones((n))/n
-        for i in range(max_iter):
-            xlast = x
-            x = numpy.dot(x,M) 
-            ## check convergence, L1 norm            
-            err=numpy.abs(x-xlast).sum()
-            if err < n*Tolerance:
-                return numpy.asarray(x).flatten()
-
-    def SVD(self, Node, dropAlpha=0.90):
-        """
-        Singular value decomposition for *Node*
-        
-        :param Node: the node you want to run SVD on.
-        :param dropAlpha: the cosine similiarity limit.
-        """
-
-        incidMatrix = self.incidenceMatrix()
-        ## |V| = nodeCount
-        nodeCount = self.number_of_nodes()
-        ## |E| = edgeCount
-        edgeCount = self.number_of_edges()+1
-        
-        ## dont run if it will just fail;
-        if nodeCount < 3 and edgeCount < 3:
-            return
-        
-        ## As you know the SVD will give you a product A = U∑V*,
-        ## where the columns of U consists of left singular vectors
-        ## for each respective singular value σ.
-        
-        ## Create the edge incidence matrix
-        U, S, Vh = linalg.svd(incidMatrix)
-        Vt = Vh.T
-
-        diagMatrix = linalg.diagsvd(S,len(incidMatrix),len(Vh))
-
-        nSigma = diagMatrix
-        U2   = numpy.mat(U)
-        V2   = numpy.mat(Vh)
-        Eig2 = numpy.mat(nSigma)
-
-        if not Node:
-            nodeList = self.nodes.items()
-            curNode = nodeList.pop(0)[0]
-        else:
-            curNode = Node
-            
-        newNode = self.incidenceOfNode(curNode, edgeCount)
-        if newNode == None:
-            return
-        
-        if Eig2.shape[0] == Eig2.shape[1]:
-            ## this shape is useless to us, singular matrix
-            return
-        
-        U    = U2.T
-        Eig  = Eig2.I.T
-        node = newNode.T
-
-        
-        node = node * U * Eig2
-        
-        each = {}
-        count = 0
-        
-        for x in V2:
-            cosineSim = (node * x.T) / (linalg.norm(x) * linalg.norm(node))
-            if cosineSim > dropAlpha:
-                each[self.nodeByNodeNum(count)] = cosineSim.A.tolist()[0][0]
-
-            count += 1
-            
-        return each
-            
-    def SVD_each(self):
-        """ run SVD on every item in the graph return
-        a list which corresponds to a dict of each SVD """
-        nodeList = self.nodes.items()
-        each = []
-        
-        while nodeList:
-            curNode = nodeList.pop(0)[0]
-            currentSVD = self.SVD(Node=curNode)
-            each.append({curNode:currentSVD})
-
-        return each
-        
-    def to_dot_file(self, primary_type=None, exclude_filter=None):
-        import pydot
-        import time
-        import cPickle
-        import hashlib
-        import os
-        
-        self_hash = hashlib.sha224(cPickle.dumps(self)).hexdigest()
-
-        unique_colors = ['skyblue1','maroon1','yellowgreen','olivedrab3','red3','royalblue3',]
-        unique_color_dict = {}
-        
-        callgraph = pydot.Dot(graph_type='digraph', fontname="Verdana", fontsize="9")
-        node_list = self.nodes.keys()
-
-        for types in self.edge_types:
-            if types != None:
-                color = unique_colors.pop()
-                unique_color_dict[types] = color
-            
-        for node in node_list:
-            for edge in self.node_out_edges(node):
-                edge_type = edge[4]
-                
-                if unique_color_dict.has_key(edge_type):
-                    color = unique_color_dict[edge_type]
-                else:
-                    color = 'black'
-                
-                if len(edge[1]) == 1:
-                    label = str(edge[1][0])
-                else:
-                    label = ','.join(map(str, edge[1]))
-                        
-                if primary_type != None and edge_type == primary_type:
-                    head = pydot.Node(edge[2], shape='doublecircle')
-                    tail = pydot.Node(edge[3], shape='doublecircle')
-                    callgraph.add_node(head)
-                    callgraph.add_node(tail)
-                        
-                    current_edge = pydot.Edge(edge[2], edge[3], label=label, color=color, weight="3", fontsize="8")
-                else:
-                    current_edge = pydot.Edge(edge[2], edge[3], label=label, color=color, fontsize="8")
-
-                callgraph.add_edge(current_edge)
-
-        if primary_type and primary_type in self.types:
-            heads = []
-            for x in self.types[primary_type]:
-                heads.append(x[0])
-            sentence = '-'.join(heads)
-            file_name = '%s-%s' % (sentence, self_hash)
-        else:
-            file_name = self_hash
-            
-        file = os.path.join('data/graphs', '%s-map.svg' % file_name.strip().replace('/','')[:100])
-        if not os.path.exists(file):
-            callgraph.write_svg(file)
-
-        print 'Graph: %s' % (file)
-
